@@ -1,4 +1,4 @@
-# $Id: FileTransfer.pm 8092 2013-07-16 14:28:57Z joostvb $
+# $Id: FileTransfer.pm 8251 2013-09-02 07:48:52Z hurko $
 # $URL: https://pong.uvt.nl/its-nettel/Netwerken/Procedures/libuvt-noc-perl/lib/UvT/NOC/FileTransfer.pm $
 
 use utf8;
@@ -8,13 +8,14 @@ use warnings FATAL => 'all';
 package UvT::NOC::FileTransfer;
 
 use parent qw( Exporter );
-our @EXPORT_OK = qw (downloadFileUsingFTP downloadFileUsingFTPS downloadFileUsingHTTPS downloadUserTrackingUsingHTTPS);
+our @EXPORT_OK = qw (downloadFileUsingFTP downloadFileUsingFTPS downloadFileUsingHTTPS downloadUserTrackingUsingHTTPS uploadFileUsingSSH uploadFileUsingSSH);
 
 use UvT::NOC::Util::FileUtil;
 use UvT::NOC::Config::Resource;
 use UvT::NOC::Net::FTPSSL;
 use Net::Lite::FTP;
 use Net::FTP;
+use Net::SCP;
 use LWP::UserAgent;
 use XML::LibXML;
 
@@ -62,7 +63,7 @@ sub downloadFileUsingFTP
 		my $ftp = Net::FTP->new($host, Debug => $debug, Passive => $passive)
 			or die "Cannot connect to $host";
 
-		if ($debug) { warn "Login\n"; }
+		if ($debug) { warn "Login with user : $username\n"; }
 		$ftp->login($username, $password)
 			or die "Cannot login : ", $ftp->message;
 
@@ -125,7 +126,7 @@ sub downloadFileUsingFTPS
         my $ftps = UvT::NOC::Net::FTPSSL->new($host, Port => $port, Encryption => $encryption, Debug => $debug)
         	or die "Cannot connect to $host";
 
-        if ($debug) { warn "Login\n"; }
+        if ($debug) { warn "Login with user : $username\n"; }
         $ftps->login($username, $password)
 			or die "Cannot login : ", $ftps->last_message;
 
@@ -292,6 +293,60 @@ sub constructUserTrackingPayload
 }
 
 
+# Functienaam : uploadFileUsingSSH
+#
+# Parameters : (4x)
+#	1) een resource-object met de volgende ssh client-gegevens :
+#		- host
+#		- username
+#		- filedir (locatie van de file op de ssh server), indien niet meegegeven wordt de standaard dir gebruikt
+#	2) de naam en directory van het te pushen bestand op het lokale filesysteem	 
+#
+# Return : -
+#
+# Omschrijving :
+#       Functie om een file te uploaden met behulp van SSH (op basis van SSH-KEYS)
+
+sub uploadFileUsingSSH
+{
+	my $resource = shift;
+	my $sourceFile = shift;
+
+	my $host = $resource->getProperty('host')->value;
+	if ($debug) { warn "Pushing $sourceFile to $host ...\n"; }
+
+	eval
+	{
+		my $username = $resource->getProperty('username')->value;
+		my $destinationDir = $resource->getProperty('destinationDir') ? $resource->getProperty('destinationDir')->value : undef;
+
+		if ($debug) { warn "Connecting to host : $host\n"; }
+		my $scp = Net::SCP->new($host)
+			or die "Cannot connect to $host";
+
+		if ($debug) { warn "Login with user : $username\n"; }
+		$scp->login($username)
+			or die "Cannot login : ", $scp->{errstr};
+
+		if ($destinationDir)
+		{
+			if ($debug) { warn "Change to destination directory : $destinationDir\n"; }
+			$scp->cwd($destinationDir)
+				or die "Cannot change to working directory : ", $scp->{errstr};
+		}
+
+		if ($debug) { warn "Put file : $sourceFile\n"; }
+		$scp->put($sourceFile)
+			or die "Cannot get file : ", $scp->{errstr};
+
+		if ($debug) { warn "Closing connection\n"; }
+		$scp->quit()
+			or die "Cannot close connection";
+	};
+	die "Error pushing file " . $sourceFile . ": $@" if $@;
+}
+
+
 # Functienaam : debug
 #
 # Parameters : (1x)
